@@ -1,13 +1,20 @@
-/* Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2014, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
+
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU General Public License, version 2.0, for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
@@ -166,7 +173,7 @@ Format_description_event::Format_description_event(uint8_t binlog_ver,
     post_header_len.insert(post_header_len.begin(), server_event_header_length,
                             server_event_header_length + number_of_event_types);
     // Sanity-check that all post header lengths are initialized.
-#ifndef DBUG_OFF
+#ifndef NDEBUG
     for (int i= 0; i < number_of_event_types; i++)
       BAPI_ASSERT(post_header_len[i] != 255);
 #endif
@@ -335,17 +342,21 @@ Format_description_event(const char* buf, unsigned int event_len,
   number_of_event_types=
    event_len - (LOG_EVENT_MINIMAL_HEADER_LEN + ST_COMMON_HEADER_LEN_OFFSET + 1);
 
-  const uint8_t *ubuf = reinterpret_cast<const uint8_t*>(buf);
-  post_header_len.insert(post_header_len.begin(),
-                         ubuf + ST_COMMON_HEADER_LEN_OFFSET + 1,
-                         (ubuf + ST_COMMON_HEADER_LEN_OFFSET + 1 +
-                          number_of_event_types));
-
   calc_server_version_split();
-  if ((ver_calc= get_product_version()) >= checksum_version_product)
-  {
+  ver_calc = get_product_version();
+  if (ver_calc >= checksum_version_product) {
     /* the last bytes are the checksum alg desc and value (or value's room) */
     number_of_event_types -= BINLOG_CHECKSUM_ALG_DESC_LEN;
+  }
+
+  const uint8_t *ubuf = reinterpret_cast<const uint8_t*>(buf) +
+                        ST_COMMON_HEADER_LEN_OFFSET + 1;
+  post_header_len.insert(post_header_len.begin(),
+                         ubuf, (ubuf + number_of_event_types));
+
+  ubuf += number_of_event_types;
+  if (ver_calc >= checksum_version_product)
+  {
     /*
       FD from the checksum-home version server (ver_calc ==
       checksum_version_product) must have
@@ -353,8 +364,7 @@ Format_description_event(const char* buf, unsigned int event_len,
     */
     BAPI_ASSERT(ver_calc != checksum_version_product ||
                 number_of_event_types == LOG_EVENT_TYPES);
-    footer()->checksum_alg= (enum_binlog_checksum_alg)
-                                  post_header_len[number_of_event_types];
+    footer()->checksum_alg= static_cast<enum_binlog_checksum_alg> (*ubuf);
   }
   else
   {
@@ -872,7 +882,8 @@ View_change_event::View_change_event(char* raw_view_id)
 : Binary_log_event(VIEW_CHANGE_EVENT),
   view_id(), seq_number(0), certification_info()
 {
-  memcpy(view_id, raw_view_id, strlen(raw_view_id));
+  strncpy(view_id, raw_view_id, sizeof(view_id)-1);
+  view_id[sizeof(view_id)-1]= 0;
 }
 
 View_change_event::
