@@ -1,5 +1,5 @@
 //
-// Copyright (C) 2010-2020 Codership Oy <info@codership.com>
+// Copyright (C) 2010-2021 Codership Oy <info@codership.com>
 //
 
 #include "replicator_smm.hpp"
@@ -326,7 +326,8 @@ void ReplicatorSMM::process_state_req(void*       recv_ctx,
                                       const void* req,
                                       size_t      req_size,
                                       wsrep_seqno_t const seqno_l,
-                                      wsrep_seqno_t const donor_seq)
+                                      wsrep_seqno_t const donor_seq,
+                                      const char* requestor_id)
 {
     assert(recv_ctx != 0);
     assert(seqno_l > -1);
@@ -451,7 +452,8 @@ void ReplicatorSMM::process_state_req(void*       recv_ctx,
                                          istr.peer(),
                                          istr.last_applied() + 1,
                                          cc_seqno_,
-                                         protocol_version_);
+                                         protocol_version_,
+                                         std::string(requestor_id));
 
                         // seqno will be unlocked when sender exists
                         seqno_lock_guard.unlock_ = false;
@@ -884,7 +886,7 @@ ReplicatorSMM::request_state_transfer (void* recv_ctx,
                 commit_monitor_.set_initial_position(-1);
                 commit_monitor_.set_initial_position(sst_seqno_);
             }
-
+            last_st_type_ = ST_TYPE_SST;
             log_debug << "Installed new state: " << state_uuid_ << ":"
                       << sst_seqno_;
         }
@@ -933,7 +935,7 @@ ReplicatorSMM::request_state_transfer (void* recv_ctx,
                 ist_prepared_ = false;
                 sst_seqno_ = ist_receiver_.finished();
             }
-
+            last_st_type_ = ST_TYPE_IST;
             // Note: apply_monitor_ must be drained to avoid race between
             // IST appliers and GCS appliers, GCS action source may
             // provide actions that have already been applied.
@@ -978,6 +980,7 @@ void ReplicatorSMM::recv_IST(void* recv_ctx)
     {
         TrxHandle* trx(0);
         int err;
+        bool fail(false);
         try
         {
             if ((err = ist_receiver_.recv(&trx)) == 0)
@@ -1028,7 +1031,15 @@ void ReplicatorSMM::recv_IST(void* recv_ctx)
                     // processed on donor, just adjust states here
                     trx->set_state(TrxHandle::S_REPLICATING);
                     trx->set_state(TrxHandle::S_CERTIFYING);
-                    apply_trx(recv_ctx, trx);
+                    try
+                    {
+                        apply_trx(recv_ctx, trx);
+                    }
+                    catch (...)
+                    {
+                         st_.mark_corrupt();
+                         throw;
+                    }
                     GU_DBUG_SYNC_WAIT("recv_IST_after_apply_trx");
                 }
             }
@@ -1042,15 +1053,25 @@ void ReplicatorSMM::recv_IST(void* recv_ctx)
             }
             trx->unref();
         }
-        catch (gu::Exception& e)
+        catch (std::exception& e)
         {
             log_fatal << "receiving IST failed, node restart required: "
                       << e.what();
+            fail = true;
+        }
+        catch (...)
+        {
+            log_fatal << "receiving IST failed, node restart required: "
+                         "unknown exception.";
+            fail = true;
+        }
+
+        if (fail)
+        {
             if (trx)
             {
                 log_fatal << "failed trx: " << *trx;
             }
-            st_.mark_corrupt();
             abort();
         }
     }
