@@ -306,7 +306,7 @@ monitor_sst_progress() {
       break;
     fi
 
-    current_size=$(du --max-depth=1 ${tmpsstdir} | tail -n 1 | awk '{print $1}')
+    current_size=$(du -b -s ${tmpsstdir} | awk '{print $1}')
     if [[ ${current_size} -eq  ${previous_size} ]]; then
       current_timeout=$((current_timeout + 1))
       sleep=1
@@ -947,7 +947,6 @@ read_cnf()
         done
     fi
 
-    # Retry the connection 30 times (at 1-second intervals)
     if [[ ! "$sockopt" =~ retry= ]]; then
         sockopt+=",retry=30"
     fi
@@ -1476,7 +1475,24 @@ send_data_from_donor_to_joiner()
 
     pushd ${dir} 1>/dev/null
     set +e
-    timeit "$msg" "$strmcmd | $tcmd; RC=( "\${PIPESTATUS[@]}" )"
+
+
+    # Implement retry logic ourselves, as nc needs it, and socat has a bug
+    # when retry is used together with timeout
+    local rc=1
+    local counter=1
+
+    # remove the retry parameter from the command
+    local ltcmd=$(echo $tcmd | sed s/,retry=[0-9]*//)
+
+    while [[ $rc -ne 0 && counter -le 30 ]]; do
+        timeit "$msg" "$strmcmd | $ltcmd; RC=( "\${PIPESTATUS[@]}" )"
+        # Retry if socat/nc returns an error
+        rc=${RC[1]}
+        counter=$((counter+1))
+        sleep 1
+    done
+
     set -e
     popd 1>/dev/null
 
