@@ -1,4 +1,4 @@
-/* Copyright (c) 2000, 2020, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2021, Oracle and/or its affiliates.
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
@@ -38,7 +38,7 @@
 #include "sql_user_table.h"
 #include <set>
 
-#ifndef DBUG_OFF
+#ifndef NDEBUG
 #define HASH_STRING_WITH_QUOTE \
         "$5$BVZy9O>'a+2MH]_?$fpWyabcdiHjfCVqId/quykZzjaA7adpkcen/uiQrtmOK4p4"
 #endif
@@ -122,7 +122,7 @@ void append_user(THD *thd, String *str, LEX_USER *user, bool comma= true,
           /*
             With old_passwords == 2 the scrambled password will be binary.
           */
-          DBUG_ASSERT(thd->variables.old_passwords == 2);
+          assert(thd->variables.old_passwords == 2);
           str->append("<secret>");
         }
         str->append("'");
@@ -443,7 +443,7 @@ bool set_and_validate_user_attributes(THD *thd,
   const char *inbuf;
   char *password= NULL;
 
-  DBUG_ASSERT(!acl_is_utility_user(Str->user.str, Str->host.str, NULL));
+  assert(!acl_is_utility_user(Str->user.str, Str->host.str, NULL));
 
   what_to_set= 0;
   /* update plugin,auth str attributes */
@@ -697,7 +697,7 @@ bool change_password(THD *thd, const char *host, const char *user,
   DBUG_ENTER("change_password");
   DBUG_PRINT("enter",("host: '%s'  user: '%s'  new_password: '%s'",
                       host,user,new_password));
-  DBUG_ASSERT(host != 0);                        // Ensured by parent
+  assert(host != 0);                        // Ensured by parent
 
   if (check_change_password(thd, host, user, new_password, new_password_len))
     DBUG_RETURN(1);
@@ -767,7 +767,7 @@ bool change_password(THD *thd, const char *host, const char *user,
       goto end;
   }
 
-  DBUG_ASSERT(acl_user->plugin.length != 0);
+  assert(acl_user->plugin.length != 0);
   
   if (!(combo=(LEX_USER*) thd->alloc(sizeof(st_lex_user))))
     DBUG_RETURN(1);
@@ -917,7 +917,7 @@ end:
 #endif /* WITH_WSREP */
 
   /* Restore the state of binlog format */
-  DBUG_ASSERT(!thd->is_current_stmt_binlog_format_row());
+  assert(!thd->is_current_stmt_binlog_format_row());
   if (save_binlog_row_based)
     thd->set_current_stmt_binlog_format_row();
 
@@ -1460,7 +1460,7 @@ bool mysql_create_user(THD *thd, List <LEX_USER> &list, bool if_not_exists)
   if ((result= open_grant_tables(thd, tables, &transactional_tables)))
   {
     /* Restore the state of binlog format */
-    DBUG_ASSERT(!thd->is_current_stmt_binlog_format_row());
+    assert(!thd->is_current_stmt_binlog_format_row());
     if (save_binlog_row_based)
       thd->set_current_stmt_binlog_format_row();
     DBUG_RETURN(result != 1);
@@ -1598,7 +1598,7 @@ bool mysql_create_user(THD *thd, List <LEX_USER> &list, bool if_not_exists)
     acl_notify_htons(thd, thd->query().str, thd->query().length);
 
   /* Restore the state of binlog format */
-  DBUG_ASSERT(!thd->is_current_stmt_binlog_format_row());
+  assert(!thd->is_current_stmt_binlog_format_row());
   if (save_binlog_row_based)
     thd->set_current_stmt_binlog_format_row();
   DBUG_RETURN(result);
@@ -1644,7 +1644,7 @@ bool mysql_drop_user(THD *thd, List <LEX_USER> &list, bool if_exists)
   if ((result= open_grant_tables(thd, tables, &transactional_tables)))
   {
     /* Restore the state of binlog format */
-    DBUG_ASSERT(!thd->is_current_stmt_binlog_format_row());
+    assert(!thd->is_current_stmt_binlog_format_row());
     if (save_binlog_row_based)
       thd->set_current_stmt_binlog_format_row();
     DBUG_RETURN(result != 1);
@@ -1727,7 +1727,7 @@ bool mysql_drop_user(THD *thd, List <LEX_USER> &list, bool if_exists)
 
   thd->variables.sql_mode= old_sql_mode;
   /* Restore the state of binlog format */
-  DBUG_ASSERT(!thd->is_current_stmt_binlog_format_row());
+  assert(!thd->is_current_stmt_binlog_format_row());
   if (save_binlog_row_based)
     thd->set_current_stmt_binlog_format_row();
   DBUG_RETURN(result);
@@ -1773,7 +1773,7 @@ bool mysql_rename_user(THD *thd, List <LEX_USER> &list)
   if ((result= open_grant_tables(thd, tables, &transactional_tables)))
   {
     /* Restore the state of binlog format */
-    DBUG_ASSERT(!thd->is_current_stmt_binlog_format_row());
+    assert(!thd->is_current_stmt_binlog_format_row());
     if (save_binlog_row_based)
       thd->set_current_stmt_binlog_format_row();
     DBUG_RETURN(result != 1);
@@ -1811,7 +1811,7 @@ bool mysql_rename_user(THD *thd, List <LEX_USER> &list)
 #endif /* WITH_WSREP */
       continue;
     }  
-    DBUG_ASSERT(user_to != 0); /* Syntax enforces pairs of users. */
+    assert(user_to != 0); /* Syntax enforces pairs of users. */
 
     /*
       Search all in-memory structures and grant tables
@@ -1881,7 +1881,7 @@ bool mysql_rename_user(THD *thd, List <LEX_USER> &list)
     acl_notify_htons(thd, thd->query().str, thd->query().length);
 
   /* Restore the state of binlog format */
-  DBUG_ASSERT(!thd->is_current_stmt_binlog_format_row());
+  assert(!thd->is_current_stmt_binlog_format_row());
   if (save_binlog_row_based)
     thd->set_current_stmt_binlog_format_row();
   DBUG_RETURN(result);
@@ -2144,7 +2144,7 @@ bool mysql_alter_user(THD *thd, List <LEX_USER> &list, bool if_exists)
   }
 
   /* Restore the state of binlog format */
-  DBUG_ASSERT(!thd->is_current_stmt_binlog_format_row());
+  assert(!thd->is_current_stmt_binlog_format_row());
   if (save_binlog_row_based)
     thd->set_current_stmt_binlog_format_row();
   DBUG_RETURN(result);
