@@ -103,8 +103,8 @@ enum enum_log_table_type
 class File_query_log
 {
   File_query_log(enum_log_table_type log_type)
-    : m_log_type(log_type), name(NULL), write_error(false), log_open(false),
-      cur_log_ext(-1)
+    : cur_log_ext(0), last_removed_ext(0), m_log_type(log_type), name(NULL),
+      write_error(false), log_open(false)
   {
     memset(&log_file, 0, sizeof(log_file));
     mysql_mutex_init(key_LOG_LOCK_log, &LOCK_log, MY_MUTEX_INIT_SLOW);
@@ -119,10 +119,13 @@ class File_query_log
   ~File_query_log()
   {
     assert(!is_open());
+    if (name != NULL)
+    {
+      my_free(name);
+      name= NULL;
+    }
     mysql_mutex_destroy(&LOCK_log);
   }
-  int rotate(ulong max_size, bool *need_purge);
-  int new_file();
 
   /** @return true if the file log is open, false otherwise. */
   bool is_open() const { return log_open; }
@@ -144,6 +147,11 @@ class File_query_log
   */
   void close();
 
+  /**
+   Change what file we log to
+  */
+  bool set_file(const char *new_name);
+
   /**
      Check if we have already printed ER_ERROR_ON_WRITE and if not,
      do so.
@@ -196,6 +204,14 @@ class File_query_log
                   const char *sql_text, size_t sql_text_len);
 
 private:
+  /** slow log rotation and purging functions */
+  bool set_rotated_name(bool need_lock);
+  bool rotate(ulong max_size);
+  bool purge_logs();
+
+  ulong cur_log_ext;
+  ulong last_removed_ext;
+
   /** Type of log file. */
   const enum_log_table_type m_log_type;
 
@@ -219,15 +235,11 @@ private:
   /** True if the file log is open, false otherwise. */
   volatile bool log_open;
 
-  ulong cur_log_ext;
-
 #ifdef HAVE_PSI_INTERFACE
   /** Instrumentation key to use for file io in @c log_file */
   PSI_file_key m_log_file_key;
 #endif
 
-  bool purge_up_to(ulong to_ext, const char *log_name);
-
   friend class Log_to_file_event_handler;
   friend class Query_logger;
 };
@@ -551,6 +563,17 @@ public:
   */
   bool reopen_log_file(enum_log_table_type log_type);
 
+  /**
+     Read log file name from global variable opt_*_logname.
+     If called from a sys_var update function, the caller
+     must hold a lock protecting the sys_var
+     (LOCK_global_system_variables, a polylock for the
+     variable, etc.).
+
+     @param log_type  QUERY_LOG_SLOW or QUERY_LOG_GENERAL
+  */
+  bool set_log_file(enum_log_table_type log_type);
+
   /**
      Check if given TABLE_LIST has a query log table name and
      optionally check if the query log is currently enabled.
