@@ -1,4 +1,4 @@
-/* Copyright (c) 2013, 2015, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2013, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -114,7 +114,7 @@ public:
   */
   static Global_THD_manager* get_instance()
   {
-    DBUG_ASSERT(thd_manager != NULL);
+    assert(thd_manager != NULL);
     return thd_manager;
   }
 
