@@ -1,4 +1,4 @@
-/* Copyright (c) 2013, 2020, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2013, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -35,7 +35,7 @@
 #include "pfs_file_provider.h"
 #include "mysql/psi/mysql_file.h"
 
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   static uint binlog_dump_count= 0;
 #endif
 using binary_log::checksum_crc32;
@@ -290,7 +290,7 @@ void Binlog_sender::init()
   /* Binary event can be vary large. So set it to max allowed packet. */
   thd->variables.max_allowed_packet= MAX_MAX_ALLOWED_PACKET;
 
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   if (opt_sporadic_binlog_dump_fail && (binlog_dump_count++ % 2))
     set_unknow_error("Master fails in COM_BINLOG_DUMP because of "
                      "--sporadic-binlog-dump-fail");
@@ -369,8 +369,8 @@ void Binlog_sender::run()
 		    const char act[]= "now "
 		    "signal dump_thread_reached_wait_point "
 		    "wait_for continue_dump_thread no_clear_event";
-		    DBUG_ASSERT(!debug_sync_set_action(current_thd,
-						       STRING_WITH_LEN(act)));
+		    assert(!debug_sync_set_action(current_thd,
+                                                  STRING_WITH_LEN(act)));
 		    };);
     mysql_bin_log.lock_index();
     if (!mysql_bin_log.is_open())
@@ -392,8 +392,8 @@ void Binlog_sender::run()
       DBUG_EXECUTE_IF("waiting_for_disable_binlog",
 		      {
 		      const char act[]= "now signal consumed_binlog";
-		      DBUG_ASSERT(!debug_sync_set_action(current_thd,
-							 STRING_WITH_LEN(act)));
+		      assert(!debug_sync_set_action(current_thd,
+                                                    STRING_WITH_LEN(act)));
 		      };);
       if (is_index_file_reopened_on_binlog_disable)
         mysql_bin_log.close(LOG_CLOSE_INDEX, true/*need_lock_log=true*/,
@@ -488,8 +488,8 @@ my_off_t Binlog_sender::send_binlog(IO_CACHE *log_cache, my_off_t start_pos)
     DBUG_EXECUTE_IF("wait_after_binlog_EOF",
                     {
                       const char act[]= "now wait_for signal.rotate_finished no_clear_event";
-                      DBUG_ASSERT(!debug_sync_set_action(current_thd,
-                                                         STRING_WITH_LEN(act)));
+                      assert(!debug_sync_set_action(current_thd,
+                                                    STRING_WITH_LEN(act)));
                     };);
   }
   return 1;
@@ -575,8 +575,8 @@ int Binlog_sender::send_events(IO_CACHE *log_cache, my_off_t end_pos)
                         const char act[]=
                           "now "
                           "wait_for signal.continue";
-                        DBUG_ASSERT(opt_debug_sync_timeout > 0);
-                        DBUG_ASSERT(!debug_sync_set_action(thd, STRING_WITH_LEN(act)));
+                        assert(opt_debug_sync_timeout > 0);
+                        assert(!debug_sync_set_action(thd, STRING_WITH_LEN(act)));
                       }
                     });
 
@@ -601,7 +601,7 @@ int Binlog_sender::send_events(IO_CACHE *log_cache, my_off_t end_pos)
                       my_sleep(2000000);
                       });
       time_t now= time(0);
-      DBUG_ASSERT(now >= m_last_event_sent_ts);
+      assert(now >= m_last_event_sent_ts);
       bool time_for_hb_event= ((ulonglong)(now - m_last_event_sent_ts)
                           >= (ulonglong)(m_heartbeat_period/1000000000UL));
       if (time_for_hb_event)
@@ -649,8 +649,8 @@ int Binlog_sender::send_events(IO_CACHE *log_cache, my_off_t end_pos)
           static const char act[] =
               "now "
               "wait_for signal.continue";
-          DBUG_ASSERT(opt_debug_sync_timeout > 0);
-          DBUG_ASSERT(!debug_sync_set_action(thd, STRING_WITH_LEN(act)));
+          assert(opt_debug_sync_timeout > 0);
+          assert(!debug_sync_set_action(thd, STRING_WITH_LEN(act)));
         }
       });
     }
@@ -791,7 +791,7 @@ int Binlog_sender::wait_new_events(my_off_t log_pos)
 
 inline int Binlog_sender::wait_with_heartbeat(my_off_t log_pos)
 {
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   ulong hb_info_counter= 0;
 #endif
   struct timespec ts;
@@ -804,7 +804,7 @@ inline int Binlog_sender::wait_with_heartbeat(my_off_t log_pos)
     if (ret != ETIMEDOUT && ret != ETIME)
       break;
 
-#ifndef DBUG_OFF
+#ifndef NDEBUG
       if (hb_info_counter < 3)
       {
         sql_print_information("master sends heartbeat message");
@@ -847,7 +847,7 @@ int Binlog_sender::check_start_file()
   char *name_ptr= NULL;
   File file;
   IO_CACHE cache;
-  const char *errmsg;
+  std::string errmsg;
   my_off_t size;
 
   if (m_start_file[0] != '\0')
@@ -872,7 +872,7 @@ int Binlog_sender::check_start_file()
       and Slave.
     */
     Sid_map* slave_sid_map= m_exclude_gtid->get_sid_map();
-    DBUG_ASSERT(slave_sid_map);
+    assert(slave_sid_map);
     global_sid_lock->wrlock();
     const rpl_sid &server_sid= gtid_state->get_server_sid();
     rpl_sidno subset_sidno= slave_sid_map->sid_to_sidno(server_sid);
@@ -883,7 +883,7 @@ int Binlog_sender::check_start_file()
     if (gtid_executed_and_owned.add_gtid_set(gtid_state->get_executed_gtids())
         != RETURN_STATUS_OK)
     {
-      DBUG_ASSERT(0);
+      assert(0);
     }
     gtid_state->get_owned_gtids()->get_gtids(gtid_executed_and_owned);
 
@@ -891,9 +891,8 @@ int Binlog_sender::check_start_file()
                                            gtid_state->get_server_sidno(),
                                            subset_sidno))
     {
-      errmsg= ER(ER_SLAVE_HAS_MORE_GTIDS_THAN_MASTER);
       global_sid_lock->unlock();
-      set_fatal_error(errmsg);
+      set_fatal_error(ER(ER_SLAVE_HAS_MORE_GTIDS_THAN_MASTER));
       return 1;
     }
     /*
@@ -924,9 +923,9 @@ int Binlog_sender::check_start_file()
     */
     if (!gtid_state->get_lost_gtids()->is_subset(m_exclude_gtid))
     {
-      mysql_bin_log.report_missing_purged_gtids(m_exclude_gtid, &errmsg);
+      mysql_bin_log.report_missing_purged_gtids(m_exclude_gtid, errmsg);
       global_sid_lock->unlock();
-      set_fatal_error(errmsg);
+      set_fatal_error(errmsg.c_str());
       return 1;
     }
     global_sid_lock->unlock();
@@ -934,9 +933,9 @@ int Binlog_sender::check_start_file()
     if (mysql_bin_log.find_first_log_not_in_gtid_set(index_entry_name,
                                                      m_exclude_gtid,
                                                      &first_gtid,
-                                                     &errmsg))
+                                                     errmsg))
     {
-      set_fatal_error(errmsg);
+      set_fatal_error(errmsg.c_str());
       return 1;
     }
     name_ptr= index_entry_name;
@@ -976,9 +975,10 @@ int Binlog_sender::check_start_file()
     return 1;
   }
 
-  if ((file= open_binlog_file(&cache, m_linfo.log_file_name, &errmsg)) < 0)
+  const char *bl_errmsg= NULL;
+  if ((file= open_binlog_file(&cache, m_linfo.log_file_name, &bl_errmsg)) < 0)
   {
-    set_fatal_error(errmsg);
+    set_fatal_error(bl_errmsg);
     return 1;
   }
 
@@ -1015,7 +1015,7 @@ void Binlog_sender::init_checksum_alg()
   {
     m_slave_checksum_alg=
       static_cast<enum_binlog_checksum_alg>(find_type((char*) entry->ptr(), &binlog_checksum_typelib, 1) - 1);
-    DBUG_ASSERT(m_slave_checksum_alg < binary_log::BINLOG_CHECKSUM_ALG_ENUM_END);
+    assert(m_slave_checksum_alg < binary_log::BINLOG_CHECKSUM_ALG_ENUM_END);
   }
 
   mysql_mutex_unlock(&m_thd->LOCK_thd_data);
@@ -1079,7 +1079,7 @@ inline int Binlog_sender::reset_transmit_packet(ushort flags, size_t event_len)
   DBUG_ENTER("Binlog_sender::reset_transmit_packet");
   DBUG_PRINT("info", ("event_len: %zu, m_packet->alloced_length: %zu",
                       event_len, m_packet.alloced_length()));
-  DBUG_ASSERT(m_packet.alloced_length() >= PACKET_MIN_SIZE);
+  assert(m_packet.alloced_length() >= PACKET_MIN_SIZE);
 
   m_packet.length(0);  // size of the content
   m_packet.qs_append('\0'); // Set this as an OK packet
@@ -1130,12 +1130,12 @@ int Binlog_sender::send_format_description_event(IO_CACHE *log_cache,
     DBUG_RETURN(1);
   }
 
-  DBUG_ASSERT(event_ptr[LOG_POS_OFFSET] > 0);
+  assert(event_ptr[LOG_POS_OFFSET] > 0);
   m_event_checksum_alg=
     Log_event_footer::get_checksum_alg((const char *)event_ptr, event_len);
 
-  DBUG_ASSERT(m_event_checksum_alg < binary_log::BINLOG_CHECKSUM_ALG_ENUM_END ||
-              m_event_checksum_alg == binary_log::BINLOG_CHECKSUM_ALG_UNDEF);
+  assert(m_event_checksum_alg < binary_log::BINLOG_CHECKSUM_ALG_ENUM_END ||
+         m_event_checksum_alg == binary_log::BINLOG_CHECKSUM_ALG_UNDEF);
 
   /* Slave does not support checksum, but binary events include checksum */
   if (m_slave_checksum_alg == binary_log::BINLOG_CHECKSUM_ALG_UNDEF &&
@@ -1234,7 +1234,7 @@ int Binlog_sender::send_format_description_event(IO_CACHE *log_cache,
         m_event_checksum_alg != binary_log::BINLOG_CHECKSUM_ALG_OFF)
       event_len-= BINLOG_CHECKSUM_LEN;
 
-    DBUG_ASSERT(event_ptr[EVENT_TYPE_OFFSET] == binary_log::START_ENCRYPTION_EVENT);
+    assert(event_ptr[EVENT_TYPE_OFFSET] == binary_log::START_ENCRYPTION_EVENT);
     Start_encryption_log_event sele(reinterpret_cast<char*>(event_ptr), event_len, m_fdle.get());
         
     if (!sele.is_valid())
@@ -1312,7 +1312,7 @@ inline int Binlog_sender::read_event(IO_CACHE *log_cache, enum_binlog_checksum_a
   size_t event_offset;
   char header[LOG_EVENT_MINIMAL_HEADER_LEN];
   int error= 0;
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   const char *packet_buffer= NULL;
 #endif
 
@@ -1323,15 +1323,15 @@ inline int Binlog_sender::read_event(IO_CACHE *log_cache, enum_binlog_checksum_a
     DBUG_RETURN(1);
 
   event_offset= m_packet.length();
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   packet_buffer= m_packet.ptr();
 #endif
 
   DBUG_EXECUTE_IF("dump_thread_before_read_event",
                   {
                     const char act[]= "now wait_for signal.continue no_clear_event";
-                    DBUG_ASSERT(!debug_sync_set_action(current_thd,
-                                                       STRING_WITH_LEN(act)));
+                    assert(!debug_sync_set_action(current_thd,
+                                                  STRING_WITH_LEN(act)));
                   };);
 
   /*
@@ -1351,14 +1351,14 @@ inline int Binlog_sender::read_event(IO_CACHE *log_cache, enum_binlog_checksum_a
     buffer by one with the size to fit the event. When encryption is on - the buffer
     will be replaced with memory allocated for storing decrypted data.
   */
-  DBUG_ASSERT(encrypt_binlog || packet_buffer == m_packet.ptr());
+  assert(encrypt_binlog || packet_buffer == m_packet.ptr());
   *event_ptr= (uchar *)m_packet.ptr() + event_offset;
 
   DBUG_PRINT("info",
              ("Read event %s",
               Log_event::get_type_str(Log_event_type
                                       ((*event_ptr)[EVENT_TYPE_OFFSET]))));
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   if (check_event_count())
     DBUG_RETURN(1);
 #endif
@@ -1481,7 +1481,7 @@ inline int Binlog_sender::after_send_hook(const char *log_file,
   return 0;
 }
 
-#ifndef DBUG_OFF
+#ifndef NDEBUG
 extern int max_binlog_dump_events;
 
 inline int Binlog_sender::check_event_count()
@@ -1540,7 +1540,7 @@ inline bool Binlog_sender::shrink_packet()
   size_t cur_buffer_size= m_packet.alloced_length();
   size_t buffer_used= m_packet.length();
 
-  DBUG_ASSERT(!(cur_buffer_size < PACKET_MIN_SIZE));
+  assert(!(cur_buffer_size < PACKET_MIN_SIZE));
 
   /*
      If the packet is already at the minimum size, just
@@ -1576,11 +1576,11 @@ inline bool Binlog_sender::shrink_packet()
     else
       m_half_buffer_size_req_counter= 0;
   }
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   if (res == false)
   {
-    DBUG_ASSERT(m_new_shrink_size <= cur_buffer_size);
-    DBUG_ASSERT(m_packet.alloced_length() >= PACKET_MIN_SIZE);
+    assert(m_new_shrink_size <= cur_buffer_size);
+    assert(m_packet.alloced_length() >= PACKET_MIN_SIZE);
   }
 #endif
   DBUG_RETURN(res);
@@ -1590,7 +1590,7 @@ inline size_t Binlog_sender::calc_grow_buffer_size(size_t current_size,
                                                    size_t min_size)
 {
   /* Check that a sane minimum buffer size was requested.  */
-  DBUG_ASSERT(min_size > PACKET_MIN_SIZE);
+  assert(min_size > PACKET_MIN_SIZE);
   if (min_size > PACKET_MAX_SIZE)
     return 0;
 
