@@ -1,4 +1,4 @@
-/* Copyright (c) 2000, 2016, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -1003,7 +1003,7 @@ void Sql_cmd_change_repl_filter::set_filter_value(List<Item>* item_list,
     break;
   default:
     /* purecov: begin deadcode */
-    DBUG_ASSERT(0);
+    assert(0);
     break;
     /* purecov: end */
   }
