@@ -1,6 +1,6 @@
 /*****************************************************************************
 
-Copyright (c) 1995, 2020, Oracle and/or its affiliates. All Rights Reserved.
+Copyright (c) 1995, 2021, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
@@ -1938,6 +1938,13 @@ public:
 	@param bpage	buffer block to be compared */
 	virtual void adjust(const buf_page_t*) = 0;
 
+	/** Adjust the value of hp for moving. This happens
+	when some other thread working on the same list
+	attempts to relocate the hp of the page.
+	@param bpage	buffer block to be compared
+	@param dpage	buffer block to be moved to */
+	void move(const buf_page_t *bpage, buf_page_t *dpage);
+
 protected:
 	/** Disable copying */
 	HazardPointer(const HazardPointer&);
@@ -2142,8 +2149,6 @@ struct buf_pool_t{
 					indexed by (space_id, offset).
 					page_hash is protected by an
 					array of mutexes. */
-	hash_table_t*	page_hash_old;	/*!< old pointer to page_hash to be
-					freed after resizing buffer pool */
 	hash_table_t*	zip_hash;	/*!< hash table of buf_block_t blocks
 					whose frames are allocated to the
 					zip buddy system,
@@ -2183,6 +2188,8 @@ struct buf_pool_t{
 					used during scan of flush_list
 					while doing flush list batch.
 					Protected by flush_list_mutex */
+	FlushHp			oldest_hp;/*!< entry pointer to scan the oldest
+					page except for system temporary */
 	UT_LIST_BASE_NODE_T(buf_page_t) flush_list;
 					/*!< base node of the modified block
 					list */
