@@ -1,6 +1,6 @@
 /*****************************************************************************
 
-Copyright (c) 1996, 2018, Oracle and/or its affiliates. All Rights Reserved.
+Copyright (c) 1996, 2021, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
@@ -604,12 +604,11 @@ Check if the transaction is being referenced. */
 
 UNIV_INLINE
 const trx_t*
-trx_arbitrate(const trx_t*	requestor,
-	      const trx_t*	holder
-#ifdef WITH_WSREP
-	      ,my_bool		sync = FALSE 
+#ifndef WITH_WSREP
+trx_arbitrate(const trx_t* requestor, const trx_t*	holder);
+#else
+trx_arbitrate(const trx_t* requestor, const trx_t*	holder, my_bool sync = FALSE);
 #endif /* WITH_WSREP */
-	     );
 
 /**
 @param[in] trx		Transaction to check
