@@ -1,4 +1,4 @@
-/* Copyright (c) 2000, 2017, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2000, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -187,7 +187,7 @@ static struct my_option my_long_options[] =
   {"correct-checksum", OPT_CORRECT_CHECKSUM,
    "Correct checksum information for table.",
    0, 0, 0, GET_NO_ARG, NO_ARG, 0, 0, 0, 0, 0, 0},
-#ifdef DBUG_OFF
+#ifdef NDEBUG
   {"debug", '#', "This is a non-debug version. Catch this and exit.",
    0, 0, 0, GET_DISABLED, OPT_ARG, 0, 0, 0, 0, 0, 0},
 #else
@@ -371,7 +371,7 @@ static void usage(void)
   puts("Used without options all tables on the command will be checked for errors");
   printf("Usage: %s [OPTIONS] tables[.MYI]\n", my_progname_short);
   printf("\nGlobal options:\n");
-#ifndef DBUG_OFF
+#ifndef NDEBUG
   printf("\
   -#, --debug=...     Output debug log. Often this is 'd:t:o,filename'.\n");
 #endif
@@ -1117,7 +1117,7 @@ static int myisamchk(MI_CHECK *param, char * filename)
                                  share->pack.header_length),
                                 1,
                                 MYF(MY_WME));
-        DBUG_ASSERT(init_res == 0);
+        assert(init_res == 0);
 	lock_memory(param);
 	if ((info->s->options & (HA_OPTION_PACK_RECORD |
 				 HA_OPTION_COMPRESS_RECORD)) ||
