@@ -1,13 +1,20 @@
-/* Copyright (c) 2011, 2015, Oracle and/or its affiliates. All rights reserved.
+/* Copyright (c) 2011, 2021, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; version 2 of the License.
+   it under the terms of the GNU General Public License, version 2.0,
+   as published by the Free Software Foundation.
+
+   This program is also distributed with certain software (including
+   but not limited to OpenSSL) that is licensed under separate terms,
+   as designated in a particular file or component or in included license
+   documentation.  The authors of MySQL hereby grant you an additional
+   permission to link the program and your derivative works with the
+   separately licensed software that they have included with MySQL.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
+   GNU General Public License, version 2.0, for more details.
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
@@ -328,7 +335,7 @@ Item_func* OptRangeTest::create_item(Item_func::Functype type,
     break;
   default:
     result= NULL;
-    DBUG_ASSERT(false);
+    assert(false);
     return result;
   }
   Item *itm= static_cast<Item*>(result);
@@ -351,7 +358,9 @@ void OptRangeTest::check_use_count(SEL_TREE *tree)
   {
     SEL_ARG *cur_range= tree->keys[i];
     if (cur_range != NULL)
+    {
       EXPECT_FALSE(cur_range->test_use_count(cur_range));
+    }
   }
 
   if (!tree->merges.is_empty())
@@ -1674,7 +1683,7 @@ TEST_F(OptRangeTest, KeyOr2)
 
   EXPECT_EQ(0UL, fld1_20->keys[1]->use_count);
   EXPECT_NE(null_arg, fld1_20->keys[1]->next_key_part);
-  EXPECT_EQ(1UL, fld1_20->keys[1]->next_key_part->use_count);
+  EXPECT_EQ(0UL, fld1_20->keys[1]->next_key_part->use_count);
 }
 
 class Mock_SEL_ARG : public SEL_ARG
@@ -1690,12 +1699,12 @@ public:
     make_root();
   }
 
-  Mock_SEL_ARG(Type type_arg, int initial_use_count, int expected_use_count)
+  Mock_SEL_ARG(Type type_arg, int initial_use_count, int expected_use_count,uint8 initial_part = 1)
     : m_expected_use_count(expected_use_count)
   {
     make_root();
     type= type_arg;
-    part= 1;
+    part= initial_part;
     left= NULL;
     use_count= initial_use_count;
     min_flag= 0;
@@ -1940,7 +1949,7 @@ TEST_F(OptRangeTest, IncrementUseCount2)
 TEST_F(OptRangeTest, CombineAlways)
 {
   // Gets decremented in key_or() before being compared > 0, triggering
-  // a DBUG_ASSERT in SEL_ARG::SEL_ARG(Type) unless the ALWAYS type is
+  // a assert in SEL_ARG::SEL_ARG(Type) unless the ALWAYS type is
   // handled.
   static const int INITIAL_USE_COUNT= 3;
 
@@ -1988,7 +1997,7 @@ TEST_F(OptRangeTest, CombineAlways2)
       next_key_part= NULL;
       make_root();
       // Gets decremented in key_or() before being compared > 0, triggering
-      // a DBUG_ASSERT in SEL_ARG::SEL_ARG(Type) unless the ALWAYS type is
+      // a assert in SEL_ARG::SEL_ARG(Type) unless the ALWAYS type is
       // handled.
       use_count= 3;
     }
@@ -2057,6 +2066,25 @@ TEST_F(OptRangeTest, AppendRange)
   EXPECT_STREQ("42 < my_field < 42", out.c_ptr());
 }
 
+TEST_F(OptRangeTest, CloneSpatialKey) {
+  Fake_RANGE_OPT_PARAM param(thd(), &m_alloc, 2, false);
+  Mock_SEL_ARG key1(SEL_ARG::KEY_RANGE, 1, 0,1);
+  Mock_SEL_ARG key2(SEL_ARG::MAYBE_KEY, 2, 0,2);
+  // dummy field
+  Mock_field_long field1("geom1");
+  key1.field = &field1;
+  key1.left = &null_element;
+  key1.next_key_part = NULL;
+  key1.min_flag |= GEOM_FLAG;
+  key1.rkey_func_flag = HA_READ_MBR_CONTAIN;
+  // check if tree is cloned along with gis flag.
+  SEL_ARG *cloned_key1 = key_and(&param, &key1, &key2, CLONE_KEY2_MAYBE);
+  EXPECT_NE(cloned_key1, &key1);
+  EXPECT_EQ(cloned_key1->rkey_func_flag, key1.rkey_func_flag);
+  key1.use_count = 0;
+  key2.use_count = 0;
+}
+
 }
 
 #undef create_tree
